# nicetrack
3D Track analysis and display

[![Join the discussion at https://github.com/WolfgangFahl/nicetrack/discussions](https://img.shields.io/github/discussions/WolfgangFahl/nicetrack)](https://github.com/WolfgangFahl/nicetrack/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/nicetrack)](https://pypi.org/project/nicetrack/)
[![Github Actions Build](https://github.com/WolfgangFahl/nicetrack/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/nicetrack/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/nicetrack.svg)](https://pypi.python.org/pypi/nicetrack/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/nicetrack.svg)](https://github.com/WolfgangFahl/nicetrack/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/nicetrack.svg)](https://github.com/WolfgangFahl/nicetrack/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/nicetrack.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Demo
[nicetrack-demo](http://nicetrack.bitplan.com/)

## Docs and Tutorials
[Wiki](https://wiki.bitplan.com/index.php/nicetrack)
